@@ -89,6 +89,9 @@ public:
                    const QModelIndex & index ) const;
     QSize sizeHint(const QStyleOptionViewItem &option,
                    const QModelIndex &index) const;
+    QWidget* createEditor(QWidget *parent,
+			  const QStyleOptionViewItem &option,
+			  const QModelIndex &index) const;
 
 protected:
     void paintArrows(QPainter *p,
