@@ -174,10 +174,11 @@ void QCGTopLevel::saveTraceSettings()
     delete lConfig;
 
     ConfigGroup* pConfig = ConfigStorage::group("TracePositions");
-    if (_eventType)
-	pConfig->setValue(QString("EventType%1").arg(key), _eventType->name());
-    if (_eventType2)
-	pConfig->setValue(QString("EventType2%1").arg(key), _eventType2->name());
+    QString eventType, eventType2;
+    if (_eventType) eventType = _eventType->name();
+    if (_eventType2) eventType2 = _eventType2->name();
+    pConfig->setValue(QString("EventType%1").arg(key), eventType);
+    pConfig->setValue(QString("EventType2%1").arg(key), eventType2);
     if (_groupType != ProfileContext::InvalidType)
 	pConfig->setValue(QString("GroupType%1").arg(key),
 			  ProfileContext::typeName(_groupType));
@@ -618,12 +619,12 @@ void QCGTopLevel::about()
 	      "phase of developing a computer program. "
 	      "QCachegrind is open-source, and it is distributed under the "
 	      "terms of the GPL v2. For details and source code, see the "
-	      "<a href=\"http://kcachegrind.sf.net\">homepage</a> of the "
+	      "<a href=\"https://kcachegrind.github.io\">homepage</a> of the "
 	      "KCachegrind project.</p>"
               "Main author and maintainer: "
 	      "<a href=\"mailto:Josef.Weidendorfer@gmx.de\">"
               "Josef Weidendorfer</a><br>"
-              "(with lots of bug fixes and porting to Qt4 by the KDE team)");
+              "(with lots of bug fixes/porting help by the KDE community)");
     QMessageBox::about(this, tr("About QCachegrind"), text);
 }
 
